@@ -40,7 +40,8 @@ from cloud_builder.cloud_logger import CBCloudLogger
 from cloud_builder.exceptions import exception_handler
 from cloud_builder.defaults import Defaults
 from cloud_builder.package_request import CBPackageRequest
-from cloud_builder.kafka import CBKafka
+from cloud_builder.message_broker import CBMessageBroker
+from cloud_builder.response import CBResponse
 from kiwi.command import Command
 from apscheduler.schedulers.background import BlockingScheduler
 from kiwi.privileges import Privileges
@@ -51,6 +52,27 @@ from typing import (
 
 @exception_handler
 def main() -> None:
+    """
+    cb-fetch - fetches a git repository and manages content
+    changes on a configurable schedule. In case of a change
+    a rebuild request is send to the message broker
+
+    The tree structure in the git repository has to follow
+    the predefined layout as follows:
+
+    projects
+    ├── ...
+    ├── PROJECT_A
+    │   └── SUB_PROJECT
+    │       └── ...
+    └── PROJECT_B
+        └── package
+            ├── cloud_builder.kiwi
+            ├── cloud_builder.yml
+            ├── package.changes
+            ├── package.spec
+            └── package.tar.xz
+    """
     args = docopt(
         __doc__,
         version='CB (fetch) version ' + __version__,
@@ -76,6 +98,9 @@ def main() -> None:
 
 
 def update_project() -> None:
+    """
+    Callback method registered with the BlockingScheduler
+    """
     Command.run(
         ['git', '-C', Defaults.get_runner_project_dir(), 'fetch', '--all']
     )
@@ -101,16 +126,30 @@ def update_project() -> None:
     Command.run(
         ['git', '-C', Defaults.get_runner_project_dir(), 'pull']
     )
-    kafka = CBKafka(
-        config_file=Defaults.get_kafka_config()
+    broker = CBMessageBroker.new(
+        'kafka', config_file=Defaults.get_kafka_config()
     )
-    for package in sorted(changed_packages.keys()):
-        log = CBCloudLogger('CBFetch', os.path.basename(package))
-        log.response(
-            {
-                'message': f'Sending update request for package: {package!r}'
-            }
+    for package_source_path in sorted(changed_packages.keys()):
+        log = CBCloudLogger('CBFetch', os.path.basename(package_source_path))
+        package_config = Defaults.get_package_config(
+            package_source_path
         )
-        package_request = CBPackageRequest()
-        package_request.set_package_source_change_request(package)
-        kafka.send_request(package_request)
+        if package_config:
+            for target in package_config.get('distributions') or []:
+                package_request = CBPackageRequest()
+                package_request.set_package_source_change_request(
+                    package_source_path, target['arch']
+                )
+                broker.send_package_request(package_request)
+                request = package_request.get_data()
+                status_flags = Defaults.get_status_flags()
+                response = CBResponse(
+                    request['request_id'], log.get_id()
+                )
+                response.set_package_update_request_response(
+                    message='Package update request scheduled',
+                    response_code=status_flags.package_update_request,
+                    package=request['package'],
+                    arch=request['arch']
+                )
+                log.response(response.get_data())
