@@ -17,13 +17,16 @@
 #
 """
 usage: cb-run -h | --help
-       cb-run --root=<root_path>
+       cb-run --root=<root_path> --request-id=<UUID>
 
 options:
     --root=<root_path>
         Path to chroot to build the package. It's required
         that cb-prepare has created that chroot for cb-run
         to work
+
+    --request-id=<UUID>
+        UUID for this build process
 """
 import os
 from docopt import docopt
@@ -33,10 +36,31 @@ from cloud_builder.defaults import Defaults
 from kiwi.privileges import Privileges
 from kiwi.command import Command
 from cloud_builder.cloud_logger import CBCloudLogger
+from cloud_builder.response import CBResponse
 
 
 @exception_handler
 def main() -> None:
+    """
+    cb-run - builds packages by calling the run.sh script
+    which must be present in the given root_path. cb-run
+    is usually called after cb-prepare which creates an
+    environment to satisfy the cb-run requirements
+
+    The called run.sh script is expected to run a program
+    that builds packages and stores them below the path
+    returned by Defaults.get_runner_results_root()
+
+    If the OBS build script is used this will be the
+    following directory lookup:
+
+    root_path
+    └── home
+        └── abuild
+
+    At the end of cb-run an information record will be send
+    to preserve the result information for later use
+    """
     args = docopt(
         __doc__,
         version='CB (run) version ' + __version__,
@@ -73,21 +97,22 @@ def main() -> None:
         status = status_flags.package_build_succeeded
         find_call = Command.run(
             [
-                'find', os.path.join(args['--root'], 'home', 'abuild'),
+                'find', os.path.join(
+                    args['--root'], Defaults.get_runner_results_root()
+                ),
                 '-name', '*.rpm'
             ]
         )
         if find_call.output:
             packages = find_call.output.strip().split(os.linesep)
 
-    log.response(
-        {
-            'identity': log.get_id(),
-            'message': 'Package build finished',
-            'status': status,
-            'package': package_name,
-            'buildlog': build_log_file,
-            'results': packages,
-            'exitcode': exit_code
-        }
+    response = CBResponse(args['--request-id'], log.get_id())
+    response.set_package_build_response(
+        message='Package build finished',
+        response_code=status,
+        package=package_name,
+        log_file=build_log_file,
+        binary_packages=packages,
+        exit_code=exit_code
     )
+    log.response(response.get_data())
