@@ -27,7 +27,12 @@ status_flags = NamedTuple(
         ('package_build_failed', str),
         ('package_build_succeeded', str),
         ('buildroot_setup_failed', str),
-        ('buildroot_setup_succeeded', str)
+        ('buildroot_setup_succeeded', str),
+        ('package_update_request', str),
+        ('package_request_accepted', str),
+        ('incompatible_build_arch', str),
+        ('reset_running_build', str),
+        ('package_not_existing', str)
     ]
 )
 
@@ -36,8 +41,45 @@ class Defaults:
     """
     Implements Cloud Builder project default values
     """
+    @staticmethod
+    def get_package_request_queue_name() -> str:
+        """
+        Return name of message queue for sending sending
+        package build requests
+        """
+        return 'cb-request'
+
+    @staticmethod
+    def get_response_queue_name() -> str:
+        """
+        Return name of message queue for sending cloud
+        builder response messages
+        """
+        return 'cb-response'
+
+    @staticmethod
+    def get_runner_results_root() -> str:
+        """
+        Returns the root path below which the used packaging
+        tool stores the build results. At the moment this
+        method is aligned to the behavior of the build tool
+        provided with the open buildservice project.
+
+        :return: directory path
+
+        :rtype: str
+        """
+        return 'home/abuild'
+
     @staticmethod
     def get_cb_logfile() -> str:
+        """
+        Return local logfile pathname
+
+        :return: file path name
+
+        :rtype: str
+        """
         return '/var/log/cloud_builder.log'
 
     @staticmethod
@@ -66,7 +108,12 @@ class Defaults:
             package_build_failed='package build failed',
             package_build_succeeded='package build succeeded',
             buildroot_setup_failed='build root setup failed',
-            buildroot_setup_succeeded='build root setup succeeded'
+            buildroot_setup_succeeded='build root setup succeeded',
+            package_update_request='package update request scheduled',
+            package_request_accepted='package request accepted',
+            incompatible_build_arch='incompatible build arch',
+            reset_running_build='reset running build',
+            package_not_existing='package does not exist'
         )
 
     @staticmethod
@@ -93,11 +140,14 @@ class Defaults:
 
         :rtype: Dict
         """
+        config_data: Dict[str, str] = {}
         config_file = filename or os.path.join(
             package_path, 'cloud_builder.yml'
         )
-        with open(config_file, 'r') as config:
-            return yaml.safe_load(config) or {}
+        if os.path.isfile(config_file):
+            with open(config_file, 'r') as config:
+                config_data = yaml.safe_load(config) or {}
+        return config_data
 
     @staticmethod
     def get_kafka_config() -> str:
