@@ -19,7 +19,6 @@ import sys
 from functools import wraps
 from typing import Callable
 from cloud_builder.logger import CBLogger
-from cloud_builder.defaults import Defaults
 from kiwi.exceptions import KiwiError
 
 
@@ -37,9 +36,7 @@ def exception_handler(func: Callable) -> Callable:
     """
     @wraps(func)
     def wrapper(*args, **kwargs):
-        log = CBLogger.get_logger(
-            logfile=Defaults.get_cb_logfile()
-        )
+        log = CBLogger.get_logger()
         try:
             return func(*args, **kwargs)
         except CBError as issue:
@@ -106,3 +103,17 @@ class CBKafkaConsumerException(CBError):
     Exception raised if an instance of KafkaConsumer
     returned an error
     """
+
+
+class CBMessageBrokerSetupError(CBError):
+    """
+    Exception raised if there is no implementation for the
+    selected message broker
+    """
+
+
+class CBSchedulerIntervalError(CBError):
+    """
+    Exception raised if the update interval for the BlockingScheduler
+    is smaller than the poll timeout of the message broker
+    """
